==> haskell-asn1-encoding-0.9.5-18-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-asn1-encoding.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: asn1-encoding
version: 0.9.5
id: asn1-encoding-0.9.5-IbtBEvbsKOBAFXA8bzYUf0
key: asn1-encoding-0.9.5-IbtBEvbsKOBAFXA8bzYUf0
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: vincent@snarc.org
stability: experimental
homepage: http://github.com/vincenthz/hs-asn1
synopsis: ASN1 data reader and writer in RAW, BER and DER forms
description:
    ASN1 data reader and writer in raw form with supports for high level forms of ASN1 (BER, and DER).
category: Data
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
indefinite: False
exposed-modules:
    Data.ASN1.BinaryEncoding Data.ASN1.BinaryEncoding.Raw
    Data.ASN1.Encoding Data.ASN1.Error Data.ASN1.Object
    Data.ASN1.Stream
hidden-modules: Data.ASN1.Prim Data.ASN1.BinaryEncoding.Parse
                Data.ASN1.BinaryEncoding.Writer Data.ASN1.Internal
                Data.ASN1.Serialize Data.ASN1.Get
abi: 813a55247d3f7f30e0938ca01ce08050
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/asn1-encoding-0.9.5
library-dirs: /usr/lib/ghc-8.2.1/site-local/asn1-encoding-0.9.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.1/asn1-encoding-0.9.5
hs-libraries: HSasn1-encoding-0.9.5-IbtBEvbsKOBAFXA8bzYUf0
depends:
    base-4.10.0.0 bytestring-0.10.8.2
    hourglass-0.2.10-6vUY2VFiM1E873akQp7ZFT
    asn1-types-0.3.2-EtZT2ZJVgtsHoacxlkz9v7
abi-depends: base-4.10.0.0=835a16347ec1b210054efd02671c29ee
             bytestring-0.10.8.2=590a7a3c0bdcf7a6a59d8c8ef548a44a
             hourglass-0.2.10-6vUY2VFiM1E873akQp7ZFT=540b953f2306e5ddebc4c5ff666854a7
             asn1-types-0.3.2-EtZT2ZJVgtsHoacxlkz9v7=b02523025f85fb9061f5832e7f501c0a
haddock-interfaces: /usr/share/doc/haskell-asn1-encoding/html/asn1-encoding.haddock
haddock-html: /usr/share/doc/haskell-asn1-encoding/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-asn1-encoding-0.9.5-19-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-asn1-encoding.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: asn1-encoding
version: 0.9.5
id: asn1-encoding-0.9.5-3Bn1hocdFrVJ4IbVdDcoyr
key: asn1-encoding-0.9.5-3Bn1hocdFrVJ4IbVdDcoyr
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: vincent@snarc.org
stability: experimental
homepage: http://github.com/vincenthz/hs-asn1
synopsis: ASN1 data reader and writer in RAW, BER and DER forms
description:
    ASN1 data reader and writer in raw form with supports for high level forms of ASN1 (BER, and DER).
category: Data
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
indefinite: False
exposed-modules:
    Data.ASN1.BinaryEncoding Data.ASN1.BinaryEncoding.Raw
    Data.ASN1.Encoding Data.ASN1.Error Data.ASN1.Object
    Data.ASN1.Stream
hidden-modules: Data.ASN1.Prim Data.ASN1.BinaryEncoding.Parse
                Data.ASN1.BinaryEncoding.Writer Data.ASN1.Internal
                Data.ASN1.Serialize Data.ASN1.Get
abi: e411207468ac32d02addafdd5cdd9537
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/asn1-encoding-0.9.5
library-dirs: /usr/lib/ghc-8.2.1/site-local/asn1-encoding-0.9.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.1/asn1-encoding-0.9.5
hs-libraries: HSasn1-encoding-0.9.5-3Bn1hocdFrVJ4IbVdDcoyr
depends:
    base-4.10.0.0 bytestring-0.10.8.2
    hourglass-0.2.10-6vUY2VFiM1E873akQp7ZFT
    asn1-types-0.3.2-Cp1wdTJG2wtISDf5jp8dcb
abi-depends: base-4.10.0.0=835a16347ec1b210054efd02671c29ee
             bytestring-0.10.8.2=590a7a3c0bdcf7a6a59d8c8ef548a44a
             hourglass-0.2.10-6vUY2VFiM1E873akQp7ZFT=540b953f2306e5ddebc4c5ff666854a7
             asn1-types-0.3.2-Cp1wdTJG2wtISDf5jp8dcb=6f061d4b57132dfc8ea34ea36018d340
haddock-interfaces: /usr/share/doc/haskell-asn1-encoding/html/asn1-encoding.haddock
haddock-html: /usr/share/doc/haskell-asn1-encoding/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
